==> walmart-report-client-0.0.171-sources.jar: com/xforceplus/walmartreport/controller/SettlementFeignApi.java <==
package com.xforceplus.walmartreport.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2022-08-31
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.walmartreport.entity.Settlement;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "walmart-report")
public interface SettlementFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/settlement/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param settlement ${table.comment}
   * @return R
   */
  @PostMapping("/settlement/add")
  public R save(@RequestBody Settlement settlement);

  /**
   * 修改${table.comment}
   * @param settlement ${table.comment}
   * @return R
   */
  @PostMapping("/settlement/update")
  public R updateById(@RequestBody Settlement settlement);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/settlement/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> walmart-report-client-0.0.252-sources.jar: com/xforceplus/walmartreport/controller/SettlementFeignApi.java <==
package com.xforceplus.walmartreport.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2022-11-23
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.walmartreport.entity.Settlement;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "walmart-report")
public interface SettlementFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/settlement/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param settlement ${table.comment}
   * @return R
   */
  @PostMapping("/settlement/add")
  public R save(@RequestBody Settlement settlement);

  /**
   * 修改${table.comment}
   * @param settlement ${table.comment}
   * @return R
   */
  @PostMapping("/settlement/update")
  public R updateById(@RequestBody Settlement settlement);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/settlement/del/{id}" )
  public R removeById(@PathVariable Long id);

}
